
# windows installation notes



## git / github

git for windows is best downloaded and installed from: [gitforwindows.org](https://gitforwindows.org/)


The github command line tools `gh` are available as a conda installation.  e.g.

'''bash
conda install gh --channel conda-forge	
'''

Or download as [].msi](https://github.com/cli/cli/releases/download/v2.14.7/gh_2.14.7_windows_amd64.msi)

## vscode
This is a great multi-functional tool for editing, and has some great extensions which allow it to run jupyter notebooks.
windows [installer](https://code.visualstudio.com/download)

extensions:
- python (from microscoft)
    - also downloads Jpyter, and Pylance
- remote-wsl


## wsl
In the long term using the WSL (windows subsystem for linux) might suit best.  This will create semi-equivalent environments to the ADWB





